pub struct TestServer { /* private fields */ }Expand description
A running test server bound to a random port.
The server is automatically stopped when this value is dropped.
Implementations
Sourceimpl TestServer
impl TestServer